==> JADE_1.9-92.tar.gz: JADE/man/MD.Rd <==
\name{MD}
\alias{MD}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Minimum Distance index MD}

\description{Computes the Minimum Distance index MD to evaluate the performance of an ICA algorithm.}

\usage{
MD(W.hat, A)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{W.hat}{The estimated square unmixing matrix W.}
  \item{A}{The true square mixing matrix A.}
}
\details{
 \deqn{MD(\hat{W},A)=\frac{1}{\sqrt{p-1}} \inf_{P D}{||PD \hat{W} A-I||,}}{MD(W.hat,A) = 1/sqrt(p-1) inf_(P D) ||P D W.hat A - I||,}
 where \eqn{P}{P} is a permutation matrix and \eqn{D}{D} a diagonal matrix with nonzero diagonal entries.
 
 The step that minimizes the index of the set over all permutation matrix can be expressed as a linear sum assignment problem (LSAP)
 for which we use as solver the Hungarian method implemented as \code{solve_LASP} in the \pkg{clue} package.
 
 Note that this function assumes the ICA model is \eqn{X = S A'}, as is assumed by \code{\link{JADE}} and \code{ics}. However \code{fastICA} and 
 \code{PearsonICA} assume \eqn{X = S A}. Therefore matrices from those functions have to be transposed first.
  
  The MD index is scaled in such a way, that it takes a value between 0 and 1. And 0 corresponds to an optimal separation.  
}
\value{The value of the MD index.}

\references{
\cite{Ilmonen, P., Nordhausen, K., Oja, H. and Ollila, E. (2010): A New Performance Index for ICA: Properties, Computation and Asymptotic Analysis. 
In Vigneron, V., Zarzoso, V., Moreau, E., Gribonval, R. and Vincent, E. (editors) \emph{Latent Variable Analysis and Signal Separation}, 229--236, Springer.}
}
\author{Klaus Nordhausen}

\seealso{\code{\link{ComonGAP}}, \code{\link{SIR}}, \code{\link{amari.error}}, \code{\link[clue]{solve_LSAP}}}
\examples{
S <- cbind(rt(1000, 4), rnorm(1000), runif(1000))
A <- matrix(rnorm(9), ncol = 3)
X <- S \%*\% t(A)

W.hat <- JADE(X, 3)$W
MD(W.hat, A)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ multivariate }

==> JADE_2.0-2.tar.gz: JADE/man/MD.Rd <==
\name{MD}
\alias{MD}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Minimum Distance index MD}

\description{Computes the Minimum Distance index MD to evaluate the performance of an ICA algorithm.}

\usage{
MD(W.hat, A)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{W.hat}{The estimated square unmixing matrix W.}
  \item{A}{The true square mixing matrix A.}
}
\details{
 \deqn{MD(\hat{W},A)=\frac{1}{\sqrt{p-1}} \inf_{P D}{||PD \hat{W} A-I||,}}{MD(W.hat,A) = 1/sqrt(p-1) inf_(P D) ||P D W.hat A - I||,}
 where \eqn{P}{P} is a permutation matrix and \eqn{D}{D} a diagonal matrix with nonzero diagonal entries.
 
 The step that minimizes the index of the set over all permutation matrix can be expressed as a linear sum assignment problem (LSAP)
 for which we use as solver the Hungarian method implemented as \code{solve_LASP} in the \pkg{clue} package.
 
 Note that this function assumes the ICA model is \eqn{X = S A'}, as is assumed by \code{\link{JADE}} and \code{ics}. However \code{fastICA} and 
 \code{PearsonICA} assume \eqn{X = S A}. Therefore matrices from those functions have to be transposed first.
  
  The MD index is scaled in such a way, that it takes a value between 0 and 1. And 0 corresponds to an optimal separation.  
}
\value{The value of the MD index.}

\references{
\cite{Ilmonen, P., Nordhausen, K., Oja, H. and Ollila, E. (2010), A New Performance Index for ICA: Properties, Computation and Asymptotic Analysis. 
In Vigneron, V., Zarzoso, V., Moreau, E., Gribonval, R. and Vincent, E. (editors) \emph{Latent Variable Analysis and Signal Separation}, 229--236, Springer.}

\cite{Nordhausen, K., Ollila, E. and Oja, H. (2011), On the Performance Indices of ICA and Blind Source Separation. In the Proceedings of \emph{2011 IEEE 12th International Workshop on Signal Processing Advances in Wireless Communications (SPAWC 2011)}, 486--490.}

\cite{Miettinen, J., Nordhausen, K. and Taskinen, S. (2017), Blind Source Separation Based on Joint Diagonalization in R: The Packages JADE and BSSasymp, \emph{Journal of Statistical Software}, \bold{76}, 1--31, <doi:10.18637/jss.v076.i02>.}
}
\author{Klaus Nordhausen}

\seealso{\code{\link{ComonGAP}}, \code{\link{SIR}}, \code{\link{amari.error}}, \code{\link[clue]{solve_LSAP}}}
\examples{
S <- cbind(rt(1000, 4), rnorm(1000), runif(1000))
A <- matrix(rnorm(9), ncol = 3)
X <- S \%*\% t(A)

W.hat <- JADE(X, 3)$W
MD(W.hat, A)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ multivariate }
